@@ -144,38 +144,38 @@ def import_rosters(years, columns=None):
 
     if not isinstance(years, (list, range)):
         raise ValueError('years input must be list or range.')
-        
+
     if min(years) < 1999:
         raise ValueError('Data not available before 1999.')
 
     if columns is None:
         columns = []
-        
+
     rosters = []
 
     for y in years:
         temp = pandas.read_csv(r'https://github.com/mrcaseb/nflfastR-roster/blob/master/data/seasons/roster_' + str(y)
                                + '.csv?raw=True', low_memory=False)
-
-        if len(columns) > 0:
-
-            temp = temp[columns]
-
         rosters.append(temp)
 
     rosters = pandas.DataFrame(pandas.concat(rosters)).rename(
         columns={'full_name': 'player_name', 'gsis_id': 'player_id'})
     rosters.drop_duplicates(subset=['season', 'player_name', 'position', 'player_id'], keep='first', inplace=True)
 
+    if len(columns) > 0:
+        rosters = rosters[columns]
+
     def calc_age(x):
         ca = pandas.to_datetime(x[0])
         bd = pandas.to_datetime(x[1])
         return ca.year - bd.year + numpy.where(ca.month > bd.month, 0, -1)
 
-    rosters['current_age'] = rosters['season'].apply(lambda x: datetime.datetime(int(x), 9, 1))
-    rosters['age'] = rosters[['current_age', 'birth_date']].apply(calc_age, axis=1)
-    rosters.drop(['current_age'], axis=1, inplace=True)
-    rosters.dropna(subset=['player_id'], inplace=True)
+    if 'birth_date' in columns and 'current_age' in columns:
+    
+        rosters['current_age'] = rosters['season'].apply(lambda x: datetime.datetime(int(x), 9, 1))
+        rosters['age'] = rosters[['current_age', 'birth_date']].apply(calc_age, axis=1)
+        rosters.drop(['current_age'], axis=1, inplace=True)
+        rosters.dropna(subset=['player_id'], inplace=True)
 
     return rosters
 
@@ -208,7 +208,84 @@ def import_schedules(years):
         
     return scheds
     
+
+def import_win_totals(years):
+
+    if not isinstance(years, (list, range)):
+        raise ValueError('years variable must be list or range.')
     
+    df = pandas.read_csv(r'https://raw.githubusercontent.com/nflverse/nfldata/master/data/win_totals.csv')
+    
+    df = df[df['season'].isin(years)]
+    
+    return df
+    
+
+def import_officials(years=None):
+
+    if years is None:
+        years = []
+    
+    if not isinstance(years, (list, range)):
+        raise ValueError('years variable must be list or range.')
+
+    df = pandas.read_csv(r'https://raw.githubusercontent.com/nflverse/nfldata/master/data/officials.csv')
+    df['season'] = df['game_id'].str[0:4].astype(int)
+    
+    if len(years) > 0:
+        df = df[df['season'].isin(years)]
+    
+    return df
+    
+    
+def import_sc_lines(years=None):
+
+    if years is None:
+        years = []
+    
+    if not isinstance(years, (list, range)):
+        raise ValueError('years variable must be list or range.')
+
+    df = pandas.read_csv(r'https://raw.githubusercontent.com/nflverse/nfldata/master/data/sc_lines.csv')
+    
+    if len(years) > 0:
+        df = df[df['season'].isin(years)]
+    
+    return df
+    
+    
+def import_draft_picks(years=None):
+
+    if years is None:
+        years = []
+    
+    if not isinstance(years, (list, range)):
+        raise ValueError('years variable must be list or range.')
+
+    df = pandas.read_csv(r'https://raw.githubusercontent.com/nflverse/nfldata/master/data/draft_picks.csv')
+    
+    if len(years) > 0:
+        df = df[df['season'].isin(years)]  
+    
+    return df
+    
+
+def import_draft_values(picks=None):
+
+    if picks is None:
+        picks = []
+    
+    if not isinstance(picks, (list, range)):
+        raise ValueError('picks variable must be list or range.')
+
+    df = pandas.read_csv(r'https://raw.githubusercontent.com/nflverse/nfldata/master/data/draft_values.csv')
+
+    if len(picks) > 0:
+        df = df[df['pick'].between(picks[0], picks[-1])]
+
+    return df        
+
+
 def clean_nfl_data(df):
 
     name_repl = {
